parse_with_mode

Function parse_with_mode 

pub fn parse_with_mode(statement: &str, mode: ParseMode) -> Result<ParseResult>
Parses input using one of PostgreSQL’s raw-parser modes.

PL/pgSQL consumers should use the mode recorded on PLpgSQL_expr instead of rewriting an expression or assignment into another SQL form.