#[repr(i32)]pub enum ReturningOptionKind {
Undefined = 0,
ReturningOptionOld = 1,
ReturningOptionNew = 2,
}Variants
Implementations
Sourceimpl ReturningOptionKind
impl ReturningOptionKind
Sourcepub fn from_i32(value: i32) -> Option<ReturningOptionKind>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ReturningOptionKind>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ReturningOptionKind, or None if value is not a valid variant.
Sourceimpl ReturningOptionKind
impl ReturningOptionKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.