#[repr(i32)]pub enum Token {
Show 545 variants
Nul = 0,
Ascii36 = 36,
Ascii37 = 37,
Ascii40 = 40,
Ascii41 = 41,
Ascii42 = 42,
Ascii43 = 43,
Ascii44 = 44,
Ascii45 = 45,
Ascii46 = 46,
Ascii47 = 47,
Ascii58 = 58,
Ascii59 = 59,
Ascii60 = 60,
Ascii61 = 61,
Ascii62 = 62,
Ascii63 = 63,
Ascii91 = 91,
Ascii92 = 92,
Ascii93 = 93,
Ascii94 = 94,
Ident = 258,
Uident = 259,
Fconst = 260,
Sconst = 261,
Usconst = 262,
Bconst = 263,
Xconst = 264,
Op = 265,
Iconst = 266,
Param = 267,
Typecast = 268,
DotDot = 269,
ColonEquals = 270,
EqualsGreater = 271,
LessEquals = 272,
GreaterEquals = 273,
NotEquals = 274,
SqlComment = 275,
CComment = 276,
AbortP = 277,
Absent = 278,
AbsoluteP = 279,
Access = 280,
Action = 281,
AddP = 282,
Admin = 283,
After = 284,
Aggregate = 285,
All = 286,
Also = 287,
Alter = 288,
Always = 289,
Analyse = 290,
Analyze = 291,
And = 292,
Any = 293,
Array = 294,
As = 295,
Asc = 296,
Asensitive = 297,
Assertion = 298,
Assignment = 299,
Asymmetric = 300,
Atomic = 301,
At = 302,
Attach = 303,
Attribute = 304,
Authorization = 305,
Backward = 306,
Before = 307,
BeginP = 308,
Between = 309,
Bigint = 310,
Binary = 311,
Bit = 312,
BooleanP = 313,
Both = 314,
Breadth = 315,
By = 316,
Cache = 317,
Call = 318,
Called = 319,
Cascade = 320,
Cascaded = 321,
Case = 322,
Cast = 323,
CatalogP = 324,
Chain = 325,
CharP = 326,
Character = 327,
Characteristics = 328,
Check = 329,
Checkpoint = 330,
Class = 331,
Close = 332,
Cluster = 333,
Coalesce = 334,
Collate = 335,
Collation = 336,
Column = 337,
Columns = 338,
Comment = 339,
Comments = 340,
Commit = 341,
Committed = 342,
Compression = 343,
Concurrently = 344,
Conditional = 345,
Configuration = 346,
Conflict = 347,
Connection = 348,
Constraint = 349,
Constraints = 350,
ContentP = 351,
ContinueP = 352,
ConversionP = 353,
Copy = 354,
Cost = 355,
Create = 356,
Cross = 357,
Csv = 358,
Cube = 359,
CurrentP = 360,
CurrentCatalog = 361,
CurrentDate = 362,
CurrentRole = 363,
CurrentSchema = 364,
CurrentTime = 365,
CurrentTimestamp = 366,
CurrentUser = 367,
Cursor = 368,
Cycle = 369,
DataP = 370,
Database = 371,
DayP = 372,
Deallocate = 373,
Dec = 374,
DecimalP = 375,
Declare = 376,
Default = 377,
Defaults = 378,
Deferrable = 379,
Deferred = 380,
Definer = 381,
DeleteP = 382,
Delimiter = 383,
Delimiters = 384,
Depends = 385,
Depth = 386,
Desc = 387,
Detach = 388,
Dictionary = 389,
DisableP = 390,
Discard = 391,
Distinct = 392,
Do = 393,
DocumentP = 394,
DomainP = 395,
DoubleP = 396,
Drop = 397,
Each = 398,
Else = 399,
EmptyP = 400,
EnableP = 401,
Encoding = 402,
Encrypted = 403,
EndP = 404,
Enforced = 405,
EnumP = 406,
ErrorP = 407,
Escape = 408,
Event = 409,
Except = 410,
Exclude = 411,
Excluding = 412,
Exclusive = 413,
Execute = 414,
Exists = 415,
Explain = 416,
Expression = 417,
Extension = 418,
External = 419,
Extract = 420,
FalseP = 421,
Family = 422,
Fetch = 423,
Filter = 424,
Finalize = 425,
FirstP = 426,
FloatP = 427,
Following = 428,
For = 429,
Force = 430,
Foreign = 431,
Format = 432,
Forward = 433,
Freeze = 434,
From = 435,
Full = 436,
Function = 437,
Functions = 438,
Generated = 439,
Global = 440,
Grant = 441,
Granted = 442,
Greatest = 443,
GroupP = 444,
Grouping = 445,
Groups = 446,
Handler = 447,
Having = 448,
HeaderP = 449,
Hold = 450,
HourP = 451,
IdentityP = 452,
IfP = 453,
Ilike = 454,
Immediate = 455,
Immutable = 456,
ImplicitP = 457,
ImportP = 458,
InP = 459,
Include = 460,
Including = 461,
Increment = 462,
Indent = 463,
Index = 464,
Indexes = 465,
Inherit = 466,
Inherits = 467,
Initially = 468,
InlineP = 469,
InnerP = 470,
Inout = 471,
InputP = 472,
Insensitive = 473,
Insert = 474,
Instead = 475,
IntP = 476,
Integer = 477,
Intersect = 478,
Interval = 479,
Into = 480,
Invoker = 481,
Is = 482,
Isnull = 483,
Isolation = 484,
Join = 485,
Json = 486,
JsonArray = 487,
JsonArrayagg = 488,
JsonExists = 489,
JsonObject = 490,
JsonObjectagg = 491,
JsonQuery = 492,
JsonScalar = 493,
JsonSerialize = 494,
JsonTable = 495,
JsonValue = 496,
Keep = 497,
Key = 498,
Keys = 499,
Label = 500,
Language = 501,
LargeP = 502,
LastP = 503,
LateralP = 504,
Leading = 505,
Leakproof = 506,
Least = 507,
Left = 508,
Level = 509,
Like = 510,
Limit = 511,
Listen = 512,
Load = 513,
Local = 514,
Localtime = 515,
Localtimestamp = 516,
Location = 517,
LockP = 518,
Locked = 519,
Logged = 520,
Mapping = 521,
Match = 522,
Matched = 523,
Materialized = 524,
Maxvalue = 525,
Merge = 526,
MergeAction = 527,
Method = 528,
MinuteP = 529,
Minvalue = 530,
Mode = 531,
MonthP = 532,
Move = 533,
NameP = 534,
Names = 535,
National = 536,
Natural = 537,
Nchar = 538,
Nested = 539,
New = 540,
Next = 541,
Nfc = 542,
Nfd = 543,
Nfkc = 544,
Nfkd = 545,
No = 546,
None = 547,
Normalize = 548,
Normalized = 549,
Not = 550,
Nothing = 551,
Notify = 552,
Notnull = 553,
Nowait = 554,
NullP = 555,
Nullif = 556,
NullsP = 557,
Numeric = 558,
ObjectP = 559,
ObjectsP = 560,
Of = 561,
Off = 562,
Offset = 563,
Oids = 564,
Old = 565,
Omit = 566,
On = 567,
Only = 568,
Operator = 569,
Option = 570,
Options = 571,
Or = 572,
Order = 573,
Ordinality = 574,
Others = 575,
OutP = 576,
OuterP = 577,
Over = 578,
Overlaps = 579,
Overlay = 580,
Overriding = 581,
Owned = 582,
Owner = 583,
Parallel = 584,
Parameter = 585,
Parser = 586,
Partial = 587,
Partition = 588,
Passing = 589,
Password = 590,
Path = 591,
Period = 592,
Placing = 593,
Plan = 594,
Plans = 595,
Policy = 596,
Position = 597,
Preceding = 598,
Precision = 599,
Preserve = 600,
Prepare = 601,
Prepared = 602,
Primary = 603,
Prior = 604,
Privileges = 605,
Procedural = 606,
Procedure = 607,
Procedures = 608,
Program = 609,
Publication = 610,
Quote = 611,
Quotes = 612,
Range = 613,
Read = 614,
Real = 615,
Reassign = 616,
Recursive = 617,
RefP = 618,
References = 619,
Referencing = 620,
Refresh = 621,
Reindex = 622,
RelativeP = 623,
Release = 624,
Rename = 625,
Repeatable = 626,
Replace = 627,
Replica = 628,
Reset = 629,
Restart = 630,
Restrict = 631,
Return = 632,
Returning = 633,
Returns = 634,
Revoke = 635,
Right = 636,
Role = 637,
Rollback = 638,
Rollup = 639,
Routine = 640,
Routines = 641,
Row = 642,
Rows = 643,
Rule = 644,
Savepoint = 645,
Scalar = 646,
Schema = 647,
Schemas = 648,
Scroll = 649,
Search = 650,
SecondP = 651,
Security = 652,
Select = 653,
Sequence = 654,
Sequences = 655,
Serializable = 656,
Server = 657,
Session = 658,
SessionUser = 659,
Set = 660,
Sets = 661,
Setof = 662,
Share = 663,
Show = 664,
Similar = 665,
Simple = 666,
Skip = 667,
Smallint = 668,
Snapshot = 669,
Some = 670,
Source = 671,
SqlP = 672,
Stable = 673,
StandaloneP = 674,
Start = 675,
Statement = 676,
Statistics = 677,
Stdin = 678,
Stdout = 679,
Storage = 680,
Stored = 681,
StrictP = 682,
StringP = 683,
StripP = 684,
Subscription = 685,
Substring = 686,
Support = 687,
Symmetric = 688,
Sysid = 689,
SystemP = 690,
SystemUser = 691,
Table = 692,
Tables = 693,
Tablesample = 694,
Tablespace = 695,
Target = 696,
Temp = 697,
Template = 698,
Temporary = 699,
TextP = 700,
Then = 701,
Ties = 702,
Time = 703,
Timestamp = 704,
To = 705,
Trailing = 706,
Transaction = 707,
Transform = 708,
Treat = 709,
Trigger = 710,
Trim = 711,
TrueP = 712,
Truncate = 713,
Trusted = 714,
TypeP = 715,
TypesP = 716,
Uescape = 717,
Unbounded = 718,
Unconditional = 719,
Uncommitted = 720,
Unencrypted = 721,
Union = 722,
Unique = 723,
Unknown = 724,
Unlisten = 725,
Unlogged = 726,
Until = 727,
Update = 728,
User = 729,
Using = 730,
Vacuum = 731,
Valid = 732,
Validate = 733,
Validator = 734,
ValueP = 735,
Values = 736,
Varchar = 737,
Variadic = 738,
Varying = 739,
Verbose = 740,
VersionP = 741,
View = 742,
Views = 743,
Virtual = 744,
Volatile = 745,
When = 746,
Where = 747,
WhitespaceP = 748,
Window = 749,
With = 750,
Within = 751,
Without = 752,
Work = 753,
Wrapper = 754,
Write = 755,
XmlP = 756,
Xmlattributes = 757,
Xmlconcat = 758,
Xmlelement = 759,
Xmlexists = 760,
Xmlforest = 761,
Xmlnamespaces = 762,
Xmlparse = 763,
Xmlpi = 764,
Xmlroot = 765,
Xmlserialize = 766,
Xmltable = 767,
YearP = 768,
YesP = 769,
Zone = 770,
FormatLa = 771,
NotLa = 772,
NullsLa = 773,
WithLa = 774,
WithoutLa = 775,
ModeTypeName = 776,
ModePlpgsqlExpr = 777,
ModePlpgsqlAssign1 = 778,
ModePlpgsqlAssign2 = 779,
ModePlpgsqlAssign3 = 780,
Uminus = 781,
}Variants
Nul = 0
Ascii36 = 36
Single-character tokens that are returned 1:1 (identical with “self” list in scan.l) Either supporting syntax, or single-character operators (some can be both) Also see https://www.postgresql.org/docs/12/sql-syntax-lexical.html#SQL-SYNTAX-SPECIAL-CHARS
“$”
Ascii37 = 37
“%”
Ascii40 = 40
“(”
Ascii41 = 41
“)”
Ascii42 = 42
“*”
Ascii43 = 43
“+”
Ascii44 = 44
“,”
Ascii45 = 45
“-”
Ascii46 = 46
“.”
Ascii47 = 47
“/”
Ascii58 = 58
“:”
Ascii59 = 59
“;”
Ascii60 = 60
“<”
Ascii61 = 61
“=”
Ascii62 = 62
“>”
Ascii63 = 63
“?”
Ascii91 = 91
“[”
Ascii92 = 92
“"
Ascii93 = 93
“]”
Ascii94 = 94
“^”
Ident = 258
Named tokens in scan.l
Uident = 259
Fconst = 260
Sconst = 261
Usconst = 262
Bconst = 263
Xconst = 264
Op = 265
Iconst = 266
Param = 267
Typecast = 268
DotDot = 269
ColonEquals = 270
EqualsGreater = 271
LessEquals = 272
GreaterEquals = 273
NotEquals = 274
SqlComment = 275
CComment = 276
AbortP = 277
Absent = 278
AbsoluteP = 279
Access = 280
Action = 281
AddP = 282
Admin = 283
After = 284
Aggregate = 285
All = 286
Also = 287
Alter = 288
Always = 289
Analyse = 290
Analyze = 291
And = 292
Any = 293
Array = 294
As = 295
Asc = 296
Asensitive = 297
Assertion = 298
Assignment = 299
Asymmetric = 300
Atomic = 301
At = 302
Attach = 303
Attribute = 304
Authorization = 305
Backward = 306
Before = 307
BeginP = 308
Between = 309
Bigint = 310
Binary = 311
Bit = 312
BooleanP = 313
Both = 314
Breadth = 315
By = 316
Cache = 317
Call = 318
Called = 319
Cascade = 320
Cascaded = 321
Case = 322
Cast = 323
CatalogP = 324
Chain = 325
CharP = 326
Character = 327
Characteristics = 328
Check = 329
Checkpoint = 330
Class = 331
Close = 332
Cluster = 333
Coalesce = 334
Collate = 335
Collation = 336
Column = 337
Columns = 338
Comment = 339
Comments = 340
Commit = 341
Committed = 342
Compression = 343
Concurrently = 344
Conditional = 345
Configuration = 346
Conflict = 347
Connection = 348
Constraint = 349
Constraints = 350
ContentP = 351
ContinueP = 352
ConversionP = 353
Copy = 354
Cost = 355
Create = 356
Cross = 357
Csv = 358
Cube = 359
CurrentP = 360
CurrentCatalog = 361
CurrentDate = 362
CurrentRole = 363
CurrentSchema = 364
CurrentTime = 365
CurrentTimestamp = 366
CurrentUser = 367
Cursor = 368
Cycle = 369
DataP = 370
Database = 371
DayP = 372
Deallocate = 373
Dec = 374
DecimalP = 375
Declare = 376
Default = 377
Defaults = 378
Deferrable = 379
Deferred = 380
Definer = 381
DeleteP = 382
Delimiter = 383
Delimiters = 384
Depends = 385
Depth = 386
Desc = 387
Detach = 388
Dictionary = 389
DisableP = 390
Discard = 391
Distinct = 392
Do = 393
DocumentP = 394
DomainP = 395
DoubleP = 396
Drop = 397
Each = 398
Else = 399
EmptyP = 400
EnableP = 401
Encoding = 402
Encrypted = 403
EndP = 404
Enforced = 405
EnumP = 406
ErrorP = 407
Escape = 408
Event = 409
Except = 410
Exclude = 411
Excluding = 412
Exclusive = 413
Execute = 414
Exists = 415
Explain = 416
Expression = 417
Extension = 418
External = 419
Extract = 420
FalseP = 421
Family = 422
Fetch = 423
Filter = 424
Finalize = 425
FirstP = 426
FloatP = 427
Following = 428
For = 429
Force = 430
Foreign = 431
Format = 432
Forward = 433
Freeze = 434
From = 435
Full = 436
Function = 437
Functions = 438
Generated = 439
Global = 440
Grant = 441
Granted = 442
Greatest = 443
GroupP = 444
Grouping = 445
Groups = 446
Handler = 447
Having = 448
HeaderP = 449
Hold = 450
HourP = 451
IdentityP = 452
IfP = 453
Ilike = 454
Immediate = 455
Immutable = 456
ImplicitP = 457
ImportP = 458
InP = 459
Include = 460
Including = 461
Increment = 462
Indent = 463
Index = 464
Indexes = 465
Inherit = 466
Inherits = 467
Initially = 468
InlineP = 469
InnerP = 470
Inout = 471
InputP = 472
Insensitive = 473
Insert = 474
Instead = 475
IntP = 476
Integer = 477
Intersect = 478
Interval = 479
Into = 480
Invoker = 481
Is = 482
Isnull = 483
Isolation = 484
Join = 485
Json = 486
JsonArray = 487
JsonArrayagg = 488
JsonExists = 489
JsonObject = 490
JsonObjectagg = 491
JsonQuery = 492
JsonScalar = 493
JsonSerialize = 494
JsonTable = 495
JsonValue = 496
Keep = 497
Key = 498
Keys = 499
Label = 500
Language = 501
LargeP = 502
LastP = 503
LateralP = 504
Leading = 505
Leakproof = 506
Least = 507
Left = 508
Level = 509
Like = 510
Limit = 511
Listen = 512
Load = 513
Local = 514
Localtime = 515
Localtimestamp = 516
Location = 517
LockP = 518
Locked = 519
Logged = 520
Mapping = 521
Match = 522
Matched = 523
Materialized = 524
Maxvalue = 525
Merge = 526
MergeAction = 527
Method = 528
MinuteP = 529
Minvalue = 530
Mode = 531
MonthP = 532
Move = 533
NameP = 534
Names = 535
National = 536
Natural = 537
Nchar = 538
Nested = 539
New = 540
Next = 541
Nfc = 542
Nfd = 543
Nfkc = 544
Nfkd = 545
No = 546
None = 547
Normalize = 548
Normalized = 549
Not = 550
Nothing = 551
Notify = 552
Notnull = 553
Nowait = 554
NullP = 555
Nullif = 556
NullsP = 557
Numeric = 558
ObjectP = 559
ObjectsP = 560
Of = 561
Off = 562
Offset = 563
Oids = 564
Old = 565
Omit = 566
On = 567
Only = 568
Operator = 569
Option = 570
Options = 571
Or = 572
Order = 573
Ordinality = 574
Others = 575
OutP = 576
OuterP = 577
Over = 578
Overlaps = 579
Overlay = 580
Overriding = 581
Owned = 582
Owner = 583
Parallel = 584
Parameter = 585
Parser = 586
Partial = 587
Partition = 588
Passing = 589
Password = 590
Path = 591
Period = 592
Placing = 593
Plan = 594
Plans = 595
Policy = 596
Position = 597
Preceding = 598
Precision = 599
Preserve = 600
Prepare = 601
Prepared = 602
Primary = 603
Prior = 604
Privileges = 605
Procedural = 606
Procedure = 607
Procedures = 608
Program = 609
Publication = 610
Quote = 611
Quotes = 612
Range = 613
Read = 614
Real = 615
Reassign = 616
Recursive = 617
RefP = 618
References = 619
Referencing = 620
Refresh = 621
Reindex = 622
RelativeP = 623
Release = 624
Rename = 625
Repeatable = 626
Replace = 627
Replica = 628
Reset = 629
Restart = 630
Restrict = 631
Return = 632
Returning = 633
Returns = 634
Revoke = 635
Right = 636
Role = 637
Rollback = 638
Rollup = 639
Routine = 640
Routines = 641
Row = 642
Rows = 643
Rule = 644
Savepoint = 645
Scalar = 646
Schema = 647
Schemas = 648
Scroll = 649
Search = 650
SecondP = 651
Security = 652
Select = 653
Sequence = 654
Sequences = 655
Serializable = 656
Server = 657
Session = 658
SessionUser = 659
Set = 660
Sets = 661
Setof = 662
Show = 664
Similar = 665
Simple = 666
Skip = 667
Smallint = 668
Snapshot = 669
Some = 670
Source = 671
SqlP = 672
Stable = 673
StandaloneP = 674
Start = 675
Statement = 676
Statistics = 677
Stdin = 678
Stdout = 679
Storage = 680
Stored = 681
StrictP = 682
StringP = 683
StripP = 684
Subscription = 685
Substring = 686
Support = 687
Symmetric = 688
Sysid = 689
SystemP = 690
SystemUser = 691
Table = 692
Tables = 693
Tablesample = 694
Tablespace = 695
Target = 696
Temp = 697
Template = 698
Temporary = 699
TextP = 700
Then = 701
Ties = 702
Time = 703
Timestamp = 704
To = 705
Trailing = 706
Transaction = 707
Transform = 708
Treat = 709
Trigger = 710
Trim = 711
TrueP = 712
Truncate = 713
Trusted = 714
TypeP = 715
TypesP = 716
Uescape = 717
Unbounded = 718
Unconditional = 719
Uncommitted = 720
Unencrypted = 721
Union = 722
Unique = 723
Unknown = 724
Unlisten = 725
Unlogged = 726
Until = 727
Update = 728
User = 729
Using = 730
Vacuum = 731
Valid = 732
Validate = 733
Validator = 734
ValueP = 735
Values = 736
Varchar = 737
Variadic = 738
Varying = 739
Verbose = 740
VersionP = 741
View = 742
Views = 743
Virtual = 744
Volatile = 745
When = 746
Where = 747
WhitespaceP = 748
Window = 749
With = 750
Within = 751
Without = 752
Work = 753
Wrapper = 754
Write = 755
XmlP = 756
Xmlattributes = 757
Xmlconcat = 758
Xmlelement = 759
Xmlexists = 760
Xmlforest = 761
Xmlnamespaces = 762
Xmlparse = 763
Xmlpi = 764
Xmlroot = 765
Xmlserialize = 766
Xmltable = 767
YearP = 768
YesP = 769
Zone = 770
FormatLa = 771
NotLa = 772
NullsLa = 773
WithLa = 774
WithoutLa = 775
ModeTypeName = 776
ModePlpgsqlExpr = 777
ModePlpgsqlAssign1 = 778
ModePlpgsqlAssign2 = 779
ModePlpgsqlAssign3 = 780
Uminus = 781
Implementations
Sourceimpl Token
impl Token
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.