pub struct ReturningOption {
pub option: i32,
pub value: String,
pub location: i32,
}Fields
option: i32value: Stringlocation: i32Implementations
Sourceimpl ReturningOption
impl ReturningOption
Sourcepub fn option(&self) -> ReturningOptionKind
pub fn option(&self) -> ReturningOptionKind
Returns the enum value of option, or the default if the field is set to an invalid enum value.
Sourcepub fn set_option(&mut self, value: ReturningOptionKind)
pub fn set_option(&mut self, value: ReturningOptionKind)
Sets option to the provided enum value.