pub struct SummaryResult {
pub tables: Vec<Table>,
pub aliases: HashMap<String, String>,
pub cte_names: Vec<String>,
pub functions: Vec<Function>,
pub filter_columns: Vec<FilterColumn>,
pub statement_types: Vec<String>,
pub truncated_query: String,
}Expand description
protobuf-c doesn’t support optional fields, so any optional strings are just an empty string if it should be the equivalent of None/nil.
These fields have // optional at the end of the line.
Upstream issue: https://github.com/protobuf-c/protobuf-c/issues/476
Fields
tables: Vec<Table>aliases: HashMap<String, String>The value here is the table name (i.e. schema.table or just table).
cte_names: Vec<String>functions: Vec<Function>filter_columns: Vec<FilterColumn>statement_types: Vec<String>truncated_query: Stringoptional, empty if truncation limit is -1