pub fn parse_with_mode(statement: &str, mode: ParseMode) -> Result<ParseResult>Expand description
Parses input using one of PostgreSQL’s raw-parser modes.
PL/pgSQL consumers should use the mode recorded on PLpgSQL_expr
instead of rewriting an expression or assignment into another SQL form.